===========================
 Extension Manager Classes
===========================

DriverManager
=============

.. autoclass:: stevedore.driver.DriverManager
   :members:
   :show-inheritance:
   :special-members:

HookManager
===========

.. autoclass:: stevedore.hook.HookManager
   :members:
   :inherited-members:
   :show-inheritance:

NamedExtensionManager
=====================

.. autoclass:: stevedore.named.NamedExtensionManager
   :members:
   :show-inheritance:

EnabledExtensionManager
=======================

.. autoclass:: stevedore.enabled.EnabledExtensionManager
   :members:
   :inherited-members:
   :show-inheritance:

DispatchExtensionManager
========================

.. autoclass:: stevedore.dispatch.DispatchExtensionManager
   :members:
   :inherited-members:
   :show-inheritance:

NameDispatchExtensionManager
============================

.. autoclass:: stevedore.dispatch.NameDispatchExtensionManager
   :members:
   :inherited-members:
   :show-inheritance:

ExtensionManager
================

.. autoclass:: stevedore.extension.ExtensionManager
   :members:
   :show-inheritance:

Extension
=========

.. autoclass:: stevedore.extension.Extension
   :members:
   :show-inheritance:

TestExtensionManager
====================

.. autoclass:: stevedore.tests.manager.TestExtensionManager
   :members:
   :show-inheritance:
